@@ -26,7 +26,7 @@ display_bus = displayio.FourWire(
 display = ST7735R(display_bus, width=128, height=128, colstart=2, rowstart=1)
 
 # Make the display context
-splash = displayio.Group(max_size=10)
+splash = displayio.Group()
 display.show(splash)
 
 color_bitmap = displayio.Bitmap(128, 128, 1)
